==> brainmodels-0.3.0.tar.gz: brainmodels-0.3.0/setup.py <==
# -*- coding: utf-8 -*-

import io
import os
import re

from setuptools import find_packages
from setuptools import setup

# obtain version string from __init__.py
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'brainmodels', '__init__.py'), 'r') as f:
    init_py = f.read()
version = re.search('__version__ = "(.*)"', init_py).groups()[0]

# obtain long description from README and CHANGES
with io.open(os.path.join(here, 'README.md'), 'r', encoding='utf-8') as f:
    README = f.read()

# setup
setup(
    name='brainmodels',
    version=version,
    description='BrainPy-Models: Brain models implemented with BrainPy.',
    long_description=README,
    long_description_content_type="text/markdown",
    author='PKU-NIP-LAB',
    author_email='adaduo@outlook.com',
    packages=find_packages(),
    python_requires='>=3.7',
    install_requires=[
        'brainpy-simulator',
        'matplotlib',
        'numpy',
    ],
    url='https://github.com/PKU-NIP-Lab/BrainPy-Models',
    keywords='computational neuroscience, '
             'brain-inspired computation',
    classifiers=[
        'Natural Language :: English',
        'Intended Audience :: Science/Research',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development :: Libraries',
    ]
)

==> brainmodels-0.3.6.tar.gz: brainmodels-0.3.6/setup.py <==
# -*- coding: utf-8 -*-

import io
import os
import re

from setuptools import find_packages
from setuptools import setup

# obtain version string from __init__.py
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'brainmodels', '__init__.py'), 'r') as f:
    init_py = f.read()
version = re.search('__version__ = "(.*)"', init_py).groups()[0]

# obtain long description from README and CHANGES
with io.open(os.path.join(here, 'README.md'), 'r', encoding='utf-8') as f:
    README = f.read()

# setup
setup(
    name='brainmodels',
    version=version,
    description='BrainModels: Brain models implemented with BrainPy',
    long_description=README,
    long_description_content_type="text/markdown",
    author='BrainPy team',
    author_email='chao.brain@qq.com',
    packages=find_packages(),
    python_requires='>=3.6',
    install_requires=[
        'brain-py',
    ],
    url='https://github.com/PKU-NIP-Lab/BrainModels',
    keywords='computational neuroscience, '
             'brain-inspired computation, ',
    classifiers=[
        'Natural Language :: English',
        'Intended Audience :: Science/Research',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development :: Libraries',
    ]
)
